@@ -9,7 +9,6 @@
 #define NGRID 10
 #define DL for (d=0;d<3;d++)
 #define NSIM 256.
-#define A 1.
 
 typedef struct Zone {
   float prob; /* Halo probability */
@@ -74,7 +73,7 @@ int main(int argc,char **argv) {
 
   float **hr,**gc,xg,yg,zg;
   int d,skippy,maxnptot,***gn,**gm,g0,g1,g2,gcrit[3];
-  float cell,a,omega_m;
+  float cell,a,omegam;
   char ok, existold;
   int halready,nhaloesoutz,nread;
 
@@ -83,20 +82,20 @@ int main(int argc,char **argv) {
 
   e1 = exp(1.)-1.;
 
-  hubble = 100.;
   halready = 0;
   
-  if (argc != 10) {
+  if (argc != 11) {
     printf("Wrong number of arguments.\n");
     printf("arg1: box size\n");
     printf("arg2: Omega_matter\n");
-    printf("arg3: position file\n");
-    printf("arg4: velocity file\n");
-    printf("arg5: volume file\n");
-    printf("arg6: input zone file\n");
-    printf("arg7: output bound zone file\n");
-    printf("arg8: output text file\n");
-    printf("arg9: unbinding f\n\n");
+    printf("arg3: scale factor a\n");
+    printf("arg4: position file\n");
+    printf("arg5: velocity file\n");
+    printf("arg6: volume file\n");
+    printf("arg7: input zone file\n");
+    printf("arg8: output bound zone file\n");
+    printf("arg9: output text file\n");
+    printf("arg10: unbinding f\n\n");
     exit(0);
   }
   if (sscanf(argv[1],"%f",&boxsize) != 1) {
@@ -104,23 +103,31 @@ int main(int argc,char **argv) {
     exit(0);
   }
   boxsize2 = boxsize/2.;
-  if (sscanf(argv[2],"%f",&omega_m) != 1) {
+  if (sscanf(argv[2],"%f",&omegam) != 1) {
     printf("%s is not a valid Omega_matter\n",argv[2]);
     exit(0);
   }
-  posfile = argv[3];
-  velfile = argv[4];
-  volfile = argv[5];
-  inzfile = argv[6];
-  outzfile = argv[7];
-  outlistfile = argv[8];
-  if (sscanf(argv[9],"%f",&potfact) != 1) {
-    printf("%s is not a valid potfact\n",argv[9]);
+  if (sscanf(argv[3],"%f",&a) != 1) {
+    printf("%s is not a valid scale factor\n",argv[3]);
+    exit(0);
+  }  
+  posfile = argv[4];
+  velfile = argv[5];
+  volfile = argv[6];
+  inzfile = argv[7];
+  outzfile = argv[8];
+  outlistfile = argv[9];
+  if (sscanf(argv[10],"%f",&potfact) != 1) {
+    printf("%s is not a valid potfact\n",argv[10]);
     exit(0);
   }
 
   cell = boxsize/NSIM;
-  potconstreal = omega_m * 3.*cell*cell*cell*100.*100./(8.*3.1415927);
+  hubble = 100. * sqrt(omegam/(a*a*a) + 1. - omegam);
+  printf("a = %f => Multiplying H0 by %e\n",a,hubble/100.);
+  /* When A != 1 */
+  potconstreal = omegam * 3.*cell*cell*cell*100.*100./(8.*3.1415927);
+  /* GM_particle, plus conversion factors to (km/sec)^2 */
 
   printf("cell, potconst = %f,%e\n",cell,potconstreal);
 
@@ -471,10 +478,10 @@ int main(int argc,char **argv) {
 	    DL {
 	      ke += sq(hubble*(p[d][p1]-p[d][z[h].core])
 		       + (v[d][p1]-z[h].v[d]));
-	      ke *= 0.5;
 	      gcrit[d] = gm[d][i] +
 		(hr[d][i] > 0.5*(gc[d][gm[d][i]]+gc[d][gm[d][i]+1]));
 	    }
+	    ke *= 0.5;
 
 	    pot = 0.;
 	    /* First see if it's bound, using a shallower, easier potential */
